diff --git a/app/pages/flightlab/medienstationen/stick-input.vue b/app/pages/flightlab/medienstationen/stick-input.vue
index 4b978a9..5a10a59 100644
--- a/app/pages/flightlab/medienstationen/stick-input.vue
+++ b/app/pages/flightlab/medienstationen/stick-input.vue
@@ -109,8 +109,8 @@
-
PUSH (Nose Down)
- PULL (Nose Up)
+ PUSH (Nase runter)
+ PULL (Nase hoch)
LEFT
RIGHT
@@ -225,9 +225,9 @@ function updateStickPosition(e: PointerEvent) {
const rawY = ((e.clientY - rect.top) / rect.height) * 2 - 1
// Clamp
stickX.value = Math.max(-1, Math.min(1, rawX))
- // Y is inverted: top of pad = forward (nose down = negative pitch input)
- // bottom of pad = pull back (nose up = positive pitch input)
- stickY.value = Math.max(-1, Math.min(1, -rawY))
+ // Screen Y: top of pad = push forward (nose down), bottom = pull back (nose up)
+ // rawY: -1 at top, +1 at bottom → matches: pull back (bottom) = positive pitch
+ stickY.value = Math.max(-1, Math.min(1, rawY))
}
// --- Throttle touch handling ---